@@ -32,6 +32,25 @@ impl<T: PrimInt> GaussianInt<T> {
     pub fn zero() -> Self {
         Self(Complex::new(T::zero(), T::zero()))
     }
+
+    /// Given a Gaussian integer z0, called a modulus,
+    /// two Gaussian integers z1, z2 are *congruent modulo z0*,
+    /// if their difference is a multiple of z0.
+    ///
+    /// # Example
+    ///
+    /// ```
+    /// # use gaussiant::GaussianInt;
+    /// # fn main() {
+    /// let c1 = GaussianInt::new(5, 0);
+    /// let c2 = GaussianInt::new(25, 0);
+    /// let c3 = GaussianInt::new(10, 0);
+    /// assert!(c1.congruent(c2, c3));
+    /// # }
+    /// ```
+    pub fn congruent(&self, other: Self, modulus: Self) -> bool {
+        (*self - other) % modulus == Self::zero()
+    }
 }
 
 impl<T: PrimInt + Signed> GaussianInt<T> {
@@ -41,16 +60,48 @@ impl<T: PrimInt + Signed> GaussianInt<T> {
     }
 
     /// Returns the norm.
+    ///
+    /// # Example
+    ///
+    /// ```
+    /// # use gaussiant::GaussianInt;
+    /// # fn main() {
+    /// let z = GaussianInt::new(2, 7);
+    /// assert_eq!(z.norm(), GaussianInt::new(53, 0));
+    /// # }
+    /// ```
     pub fn norm(&self) -> Self {
         *self * self.conj()
     }
 
     /// Returns `true` if `self` is a divisor of `other`.
+    ///
+    /// # Example
+    ///
+    /// ```
+    /// # use gaussiant::GaussianInt;
+    /// # fn main() {
+    /// let c1 = GaussianInt::new(5, 0);
+    /// let c2 = GaussianInt::new(1, 2);
+    /// assert_eq!(c1 / c2, GaussianInt::new(1, -2));
+    /// # }
+    /// ```
     pub fn is_divisor_of(&self, other: Self) -> bool {
         (other % *self) == Self::zero() && !(other.0.re != T::zero() && other.0.im != T::zero())
     }
 
     /// Tests whether a Gaussian integer is a rational integer.
+    ///
+    /// # Example
+    ///
+    /// ```
+    /// # use gaussiant::GaussianInt;
+    /// # fn main() {
+    /// let z = GaussianInt::new(2, 7);
+    /// let z2 = GaussianInt::new(0, -7);
+    /// assert!((z + z2).is_rational());
+    /// # }
+    /// ```
     pub fn is_rational(&self) -> bool {
         self.0.im == T::zero()
     }
@@ -68,17 +119,27 @@ impl<T: PrimInt + Signed> GaussianInt<T> {
     ///    (which will not be of the form 4*n* + 3).
     ///
     /// [Gaussian primality]: https://en.wikipedia.org/wiki/Gaussian_integer#Gaussian_primes
+    ///
+    /// # Example
+    ///
+    /// ```
+    /// # use gaussiant::GaussianInt;
+    /// # fn main() {
+    /// let z = GaussianInt::new(2, 7);
+    /// assert!(z.is_gaussian_prime());
+    /// # }
+    /// ```
     pub fn is_gaussian_prime(&self) -> bool {
         let a = self.0.re;
         let b = self.0.im;
 
         let condition_1 = match (a.is_zero(), b.is_zero()) {
             (true, false) => {
-                let other = b.to_i32().unwrap();
+                let other = b.to_isize().unwrap();
                 is_prime(other) && (other - 3) % 4 == 0
             }
             (false, true) => {
-                let other = a.to_i32().unwrap();
+                let other = a.to_isize().unwrap();
                 is_prime(other) && (other - 3) % 4 == 0
             }
             _ => false,
@@ -86,10 +147,10 @@ impl<T: PrimInt + Signed> GaussianInt<T> {
 
         let condition_2 = match (a.is_zero(), b.is_zero()) {
             (false, false) => {
-                let a = a.to_i32().unwrap();
-                let b = b.to_i32().unwrap();
+                let a = a.to_isize().unwrap();
+                let b = b.to_isize().unwrap();
                 let both_prime = is_prime(a) && is_prime(b);
-                let sum_of_squares = i32::pow(a, 2) + i32::pow(b, 2);
+                let sum_of_squares = isize::pow(a, 2) + isize::pow(b, 2);
                 let sum_of_squares_is_4n_plus_3 = (sum_of_squares - 3) % 4 == 0;
                 both_prime && is_prime(sum_of_squares) && !sum_of_squares_is_4n_plus_3
             }
@@ -100,6 +161,24 @@ impl<T: PrimInt + Signed> GaussianInt<T> {
     }
 }
 
+impl GaussianInt<isize> {
+    /// Tests whether a Gaussian integer is "even."
+    ///
+    /// See <https://en.wikipedia.org/wiki/Gaussian_integer#Examples>.
+    pub fn is_even(&self) -> bool {
+        self.congruent(Self::zero(), Self::new(1, 1))
+    }
+
+    /// Tests whether a Gaussian integer is "odd."
+    ///
+    /// See <https://en.wikipedia.org/wiki/Gaussian_integer#Examples>.
+    pub fn is_odd(&self) -> bool {
+        let one = Self::new(1, 0);
+        self.congruent(one, Self::new(1, 1))
+        // *self % (Self::new(1, 1) + one) == Self::zero()
+    }
+}
+
 impl<T: PrimInt + Signed> GaussianInt<T>
 where
     f64: From<T>,
@@ -148,19 +227,13 @@ impl<T: PrimInt> From<Complex<T>> for GaussianInt<T> {
     }
 }
 
-impl<T: PrimInt> From<GaussianInt<T>> for i32 {
-    fn from(g: GaussianInt<T>) -> Self {
-        g.0.re.to_i32().unwrap()
-    }
-}
-
 impl<T: PrimInt> From<GaussianInt<T>> for isize {
     fn from(g: GaussianInt<T>) -> Self {
         g.0.re.to_isize().unwrap()
     }
 }
 
-fn is_prime(number: i32) -> bool {
+fn is_prime(number: isize) -> bool {
     for i in 2..(number / 2 + 1) {
         if number % i == 0 {
             return false;
