@@ -98,22 +98,16 @@ mod tests {
         assert!(five.is_divisor_of(five));
     }
 
-    #[test]
-    fn from_i32() {
-        let c = GaussianInt::new(5, 0);
-        assert_eq!(5i32, c.into());
-    }
-
     #[test]
     fn from_isize() {
         let c = GaussianInt::new(5, 0);
-        assert_eq!(5isize, c.into());
+        assert_eq!(5_isize, c.into());
     }
 
     #[test]
     fn conjugate() {
-        let c: GaussianInt<i32> = GaussianInt::new(5, 5);
-        let conj: GaussianInt<i32> = GaussianInt::new(5, -5);
+        let c: GaussianInt<isize> = GaussianInt::new(5, 5);
+        let conj: GaussianInt<isize> = GaussianInt::new(5, -5);
         assert_eq!(c.conj(), conj);
     }
 
@@ -153,4 +147,27 @@ mod tests {
         let c = GaussianInt::new(0, -1);
         assert_eq!(c.to_polar(), (1f64, -std::f64::consts::PI / 2f64));
     }
+    #[test]
+    fn congruence() {
+        let c1 = GaussianInt::new(5, 0);
+        let c2 = GaussianInt::new(25, 0);
+        let c3 = GaussianInt::new(10, 0);
+        assert!(c1.congruent(c2, c3));
+    }
+
+    #[test]
+    fn is_even() {
+        let z = GaussianInt::new(4, 0);
+        assert!(z.is_even());
+        let z = GaussianInt::new(-3, 1);
+        assert!(z.is_even());
+    }
+
+    #[test]
+    fn is_odd() {
+        let z = GaussianInt::new(1, 0);
+        assert!(z.is_odd());
+        let z = GaussianInt::new(2, 1);
+        assert!(z.is_odd());
+    }
 }
